import ecdsa
from ecdsa import SigningKey, VerifyingKey
from hashlib import sha256, sha384

def generate_ecdsa_key_pair():
    try:
        private_key = SigningKey.generate(ecdsa.NIST384p)
        pem_private_key = private_key.to_pem()
        pem_public_key = private_key.get_verifying_key().to_pem()

        with open("private-ecdsa.pem", "wb") as private_key_file:
            private_key_file.write(pem_private_key)

        with open("public-ecdsa.pem", "wb") as public_key_file:
            public_key_file.write(pem_public_key)

        print("ECDSA key pair generation successful")
    except Exception as e:
        print(f"An error occurred: {e}")

#generate_ecdsa_key_pair()
#signature = None
def digital_sign_message(message):
    try:
        with open("private-ecdsa.pem") as f:
            private_key = SigningKey.from_pem(f.read())
        #signature = private_key.sign(message.encode(), hashfunc=sha384, sigencode=ecdsa.util.sigencode_pem)
        signature = private_key.sign(message.encode(), hashfunc=sha384)
        with open("ecdsa-sign.sig", "wb") as f:
            f.write(signature)
        print(f"Digital Signature: {signature.hex()}")
    except Exception as e:
        print("Error signing message: ",e)

digital_sign_message("Hi! I am Anoop")

def verify_digital_signature():
    try:
        with open("ecdsa-sign.sig", "rb") as f:
            signature = f.read()
        message = "Hi! I am Anoop".encode()
        with open("public-ecdsa.pem") as f:
            public_key = VerifyingKey.from_pem(f.read())
        #public_key.verify(signature, message, hashfunc=sha384,sigdecode=ecdsa.util.sigdecode_pem)
        public_key.verify(signature, message, hashfunc=sha384)
        print("Digital Signature is valid.")
    except Exception as e:
        print(e)

verify_digital_signature()